@@ -1,7 +1,7 @@
 package App::LintPrereqs;
 
-our $DATE = '2015-04-11'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $DATE = '2015-05-15'; # DATE
+our $VERSION = '0.26'; # VERSION
 
 use 5.010001;
 use strict;
@@ -132,6 +132,13 @@ sub lint_prereqs {
                        "Are you in the right dir (dist top-level)? ".
                            "Is your dist managed by Dist::Zilla?"];
 
+    my $ct = do {
+        open my($fh), "<", "dist.ini" or die "Can't open dist.ini: $!";
+        local $/;
+        ~~<$fh>;
+    };
+    return [200, "Not run (no-lint-prereqs)"] if $ct =~ /^;!no-lint-prereqs$/m;
+
     my $cfg = Config::IniFiles->new(-file => "dist.ini", -fallback => "ALL");
     $cfg or return [
         500, "Can't open dist.ini: ".join(", ", @Config::IniFiles::errors)];
@@ -244,6 +251,31 @@ sub lint_prereqs {
         }
     }
 
+    {
+        no strict 'refs';
+        my %lumped_mods;
+        for my $mod (keys %mods_from_ini) {
+            next unless $mod =~ /::Lumped$/;
+            my $mod_pm = $mod;
+            $mod_pm =~ s!::!/!g;
+            $mod_pm .= ".pm";
+            require $mod_pm;
+            my $lm = \@{"$mod\::LUMPED_MODULES"};
+            for (@$lm) { $lumped_mods{$_} = $mod }
+        }
+        last unless %lumped_mods;
+        $log->tracef("Checking lumped modules");
+        for my $mod (keys %lumped_mods) {
+            if (exists $mods_from_ini{$mod}) {
+                push @errs, {
+                    module => $mod,
+                    error  => "Listed in dist.ini but already lumped in $lumped_mods{$mod}",
+                    remedy => "Remove one of $mod or $lumped_mods{$mod} from dist.ini",
+                };
+            }
+        }
+    }
+
     for my $mod (keys %mods_from_scanned) {
         next if $mod eq 'perl';
         my $v = $mods_from_scanned{$mod};
@@ -283,7 +315,7 @@ App::LintPrereqs - Check extraneous/missing prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.25 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-04-11.
+This document describes version 0.26 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-05-15.
 
 =head1 SYNOPSIS
 
